-- parameters:
--
-- location_id: Location to generate the report for

WITH
sales_by_item_id AS (
  SELECT
    inventory_line AS item_id,
    max(snack_sales_log_timestamp) AS last_sold,
    count(*)::int AS units_sold
  FROM garfield.snack_sales_log
  WHERE type_id = 'SNACK_BUY'
    AND inventory_line IS NOT NULL
    AND snack_sales_log_timestamp > NOW() - INTERVAL '120 days'
    AND location_id = %(location_id)s
  GROUP BY item_id
),
sales_by_barcode AS (
  SELECT
    item_barcode,
    max(name) AS name,
    sum(units_sold) AS units_sold,
    round(avg((units_sold / extract(epoch FROM (CASE WHEN available THEN now() ELSE last_sold END) - bought)) * 86400)::numeric, 2) AS sold_per_day
  FROM sales_by_item_id
  LEFT JOIN garfield.inventory_items USING (item_id)
  GROUP BY item_barcode
),
current_inventory AS (
  SELECT
    item_barcode,
    sum(units_left)::int AS units_left
  FROM all_inventory_item_overview
  WHERE available
    AND location = %(location_id)s
  GROUP BY item_barcode
)

SELECT
  sales_by_barcode.*,
  COALESCE(current_inventory.units_left, 0)::int AS units_left
FROM sales_by_barcode
LEFT JOIN current_inventory USING (item_barcode)
ORDER BY units_sold DESC
